pub async fn dispatch_request(
request: JmapRequest,
user: &str,
store: &dyn MailStore,
) -> JmapResponseExpand description
Run an entire JMAP request through the dispatcher and return the response envelope. Back-references between method calls are resolved before each dispatch.