pub struct InMemoryStore { /* private fields */ }Expand description
Implementations
Sourceimpl InMemoryStore
impl InMemoryStore
Sourcepub fn with_mailbox(self, id: i64, name: &str) -> Self
pub fn with_mailbox(self, id: i64, name: &str) -> Self
Append a mailbox with the given id and name.
Sourcepub fn with_message(self, msg: Message) -> Self
pub fn with_message(self, msg: Message) -> Self
Append a pre-built Message. Use make_message for a sane default
shape and mutate before passing in if you need overrides.
Sourcepub fn with_message_raw(self, msg_id: i64, raw: Vec<u8>) -> Self
pub fn with_message_raw(self, msg_id: i64, raw: Vec<u8>) -> Self
Map a message id to raw RFC 5322 bytes. MailStore::read_message_raw
returns these bytes; without this setter that method returns None.
Sourcepub fn with_parsed_body(self, raw: Vec<u8>, parsed: ParsedBody) -> Self
pub fn with_parsed_body(self, raw: Vec<u8>, parsed: ParsedBody) -> Self
Map a specific raw byte sequence to a parsed body. The store’s
MailStore::parse_message returns the override when called with
matching bytes, and ParsedBody::default() otherwise.
Sourcepub fn with_mailbox_counts(self, mb_id: i64, counts: MailboxCounts) -> Self
pub fn with_mailbox_counts(self, mb_id: i64, counts: MailboxCounts) -> Self
Override mailbox counts for a specific mailbox id. Without this the store derives total/unread from the message list.
Sourcepub fn list_mailboxes_fails(self, msg: &str) -> Self
pub fn list_mailboxes_fails(self, msg: &str) -> Self
Make MailStore::list_mailboxes return an error carrying msg.
Sourcepub fn mailbox_status_fails(self, msg: &str) -> Self
pub fn mailbox_status_fails(self, msg: &str) -> Self
Make MailStore::mailbox_status return an error carrying msg.
Sourcepub fn list_messages_fails(self, msg: &str) -> Self
pub fn list_messages_fails(self, msg: &str) -> Self
Make MailStore::list_messages return an error carrying msg.
Sourcepub fn get_message_fails(self, msg: &str) -> Self
pub fn get_message_fails(self, msg: &str) -> Self
Make MailStore::get_message_by_db_id return an error carrying msg.
Sourcepub fn list_thread_messages_fails(self, msg: &str) -> Self
pub fn list_thread_messages_fails(self, msg: &str) -> Self
Make MailStore::list_thread_messages return an error carrying msg.
Sourcepub fn update_flags_fails(self, msg: &str) -> Self
pub fn update_flags_fails(self, msg: &str) -> Self
Make MailStore::update_flags return an error carrying msg.
Sourcepub fn add_flags_fails(self, msg: &str) -> Self
pub fn add_flags_fails(self, msg: &str) -> Self
Make MailStore::add_flags return an error carrying msg.
Sourcepub fn submission_fails_with(self, msg: &str) -> Self
pub fn submission_fails_with(self, msg: &str) -> Self
Configure MailStore::submit_message to fail with a description.
Sourcepub fn submission_fails_silently(self) -> Self
pub fn submission_fails_silently(self) -> Self
Configure MailStore::submit_message to fail without a description.