pub struct Message {Show 16 fields
pub id: i64,
pub mailbox_id: i64,
pub uid: u32,
pub sender: String,
pub recipients: String,
pub subject: String,
pub date: i64,
pub size: u32,
pub flags: u32,
pub internal_date: i64,
pub message_id: String,
pub in_reply_to: String,
pub thread_id: String,
pub user_address: String,
pub new_content: Option<String>,
pub blob_id: String,
}Expand description
A single message as JMAP needs to see it for Email/get, Email/query,
Email/set, Thread/get, and EmailSubmission/set.
JMAP-visible email id is msg-{id}.
Fields
id: i64Store-native primary key. Rendered on the wire as msg-{id}.
mailbox_id: i64FK into the message’s containing mailbox.
uid: u32IMAP-style UID within mailbox_id. Combined with mailbox_id it
uniquely identifies the row for flag updates.
sender: StringRaw From: header value, may include a display name (e.g.
"Alice" <alice@example.com>).
recipients: StringRaw To: header value. Comma-separated address list.
subject: StringDecoded Subject: header.
date: i64Date: header epoch seconds.
size: u32Message size in bytes.
flags: u32Flag bitmask. See the FLAG_* constants in this module.
internal_date: i64Internal delivery time epoch seconds.
message_id: StringMessage-ID: header value, without the angle brackets.
in_reply_to: StringIn-Reply-To: header value, without angle brackets, or empty when
the message is not a reply.
thread_id: StringStore-defined thread identifier, stable across all messages in the same conversation.
user_address: StringOwner’s full address (used to read the raw bytes from a store).
new_content: Option<String>Optional pre-extracted plain-text snippet, used for preview.
blob_id: StringImplementation-defined opaque id used by crate::store::MailStore::read_message_raw
to locate the on-disk / blob copy of the message.